# Python tools for SDReWire

This repository contains Python tools for [SDReWire](https://github.com/randomplum/sdrewire).
Currently the command line utility `sdrewirectl` is the only utility.

Muxing can be controlled using:
```
sdrewire sdmux ts
sdrewire sdmux dut
```
